@@ -4,6 +4,43 @@ import os, sys
 from rapid import main
 import models
 from PyQt4 import QtCore, QtGui
+from rapid.ui.text.interaction import TextUserInteraction
+from rapid.unitsync.api import get_writable_data_directory
+
+def split_on_condition(seq, condition):
+	#see http://stackoverflow.com/questions/949098/python-split-a-list-based-on-a-condition
+	a, b = [], []
+	for item in seq:
+		(a if condition(item) else b).append(item)
+	return a,b
+
+class ReloadThread(QtCore.QThread):
+
+	def __init__(self, mainWidget,options, parent = None):
+		QtCore.QThread.__init__(self, parent)
+		self.mainWidget = mainWidget
+		self.options = options
+
+	def stop(self):
+		self.wait() # waits until run stops on his own
+
+	def run(self):
+		#progress = QtGui.QProgressDialog( "Loading data", "EUDE", 0, 0 )
+		#progress.show()
+		ui = TextUserInteraction()
+		if self.options.datadir:
+			main.init(options.datadir, ui)
+		elif self.options.unitsync:
+			main.init(get_writable_data_directory(), ui)
+		elif os.name == 'posix':
+			main.init(os.path.expanduser('~/.spring'), ui)
+		else:
+			print 'No data directory specified. Specify one using either --datadir or --unitsync.'
+			print
+		installed,available = split_on_condition( main.rapid.packages, lambda p: p.installed )
+		self.mainWidget.reload( installed,available )
+		#progress.destroy()
+		self.stop()
 
 class DownloadDialog(QtGui.QProgressDialog):
 	def __init__(self,parent,tag):
@@ -89,7 +126,6 @@ class InstalledRapidListWidget(RapidListWidgetBase):
 		super(InstalledRapidListWidget, self).__init__(parent)
 		self.sourceModel = models.InstalledRapidModel(self)
 		self.proxyModel.setSourceModel( self.sourceModel )
-		self.sourceModel.reload()
 		self.proxyView.doubleClicked.connect(self.doubleClicked)
 
 	def doubleClicked(self,modelIndex):
@@ -127,7 +163,6 @@ class AvailableRapidListWidget(RapidListWidgetBase):
 		super(AvailableRapidListWidget, self).__init__(parent)
 		self.sourceModel = models.AvailableRapidModel(self)
 		self.proxyModel.setSourceModel( self.sourceModel )
-		self.sourceModel.reload()
 		self.proxyView.doubleClicked.connect(self.doubleClicked)
 
 	def doubleClicked(self,modelIndex):
@@ -139,28 +174,49 @@ class AvailableRapidListWidget(RapidListWidgetBase):
 		self.connect( self.dl.dt, QtCore.SIGNAL("downloadComplete"), self.parent.reload, QtCore.Qt.QueuedConnection )
 
 class MainRapidWidget(QtGui.QWidget):
+	
 	def __init__(self,parent):
 		super(MainRapidWidget, self).__init__(parent)
+		QtCore.QObject.connect(self, QtCore.SIGNAL("reload()"), reload)
 		self.availableWidget = AvailableRapidListWidget(self)
 		self.installedWidget = InstalledRapidListWidget(self)
 		mainLayout = QtGui.QHBoxLayout(self)
 		leftLayout = QtGui.QVBoxLayout(self)
-		leftLayout.addWidget( QtGui.QLabel("Availabe tags (double-click to install)", parent ) , stretch=0 )
+		self.leftLabel = QtGui.QLabel("loading..", parent )
+		leftLayout.addWidget( self.leftLabel, stretch=0 )
 		leftLayout.addWidget( self.availableWidget, stretch=1 )
 		rightLayout = QtGui.QVBoxLayout(self)
-		rightLayout.addWidget( QtGui.QLabel("Installed tags (double-click to uninstall)", parent ) , stretch=0 )
+		self.rightLabel = QtGui.QLabel("loading..", parent )
+		rightLayout.addWidget( self.rightLabel, stretch=0 )
 		rightLayout.addWidget( self.installedWidget, stretch=1 )
 		mainLayout.addLayout( leftLayout )
 		mainLayout.addLayout( rightLayout )
 		self.setLayout( mainLayout )
-		self.setMinimumSize(1034,768)
 
-	def reload(self):
-		self.availableWidget.sourceModel.reload()
-		self.installedWidget.sourceModel.reload()
+	def reload(self,installed,available):
+		self.leftLabel.setText( "reloading..." )
+		self.rightLabel.setText( "reloading..." )
+		self.availableWidget.sourceModel.loadData( available )
+		self.installedWidget.sourceModel.loadData( installed )
+		self.leftLabel.setText("Availabe tags (double-click to install)")
+		self.rightLabel.setText("Installed tags (double-click to uninstall)")
 
 class RapidGUI(QtGui.QMainWindow):
-	def __init__(self):
+	def __init__(self,options):
 		QtGui.QMainWindow.__init__(self)
+		settings = QtCore.QSettings()
+		settings.beginGroup("MainWindow");
+		self.resize(settings.value("size", QtCore.QSize(600, 480)).toSize());
+		self.move(settings.value("pos", QtCore.QPoint(200, 200)).toPoint());
+		settings.endGroup();
 		self.mainWidget = MainRapidWidget(self)
 		self.setCentralWidget(self.mainWidget)
+		self.reloadThread = ReloadThread( self.mainWidget,options )
+		self.reloadThread.start()
+		
+	def closeEvent (self, event):
+		settings = QtCore.QSettings()
+		settings.beginGroup("MainWindow");
+		settings.setValue("size", self.size())
+		settings.setValue("pos", self.pos())
+		settings.endGroup()
