@@ -1,11 +1,9 @@
 # Author: Tobi Vollebregt
 
 from .gui import RapidGUI
-from rapid.ui.text.interaction import TextUserInteraction
 from optparse import OptionParser
-from rapid.main import init
-from rapid.unitsync.api import get_writable_data_directory
-import os
+import os,sys
+
 try:
 	from PyQt4 import QtGui
 except:
@@ -14,7 +12,6 @@ except:
 		"Please use your package manager to install PyQt4 and then run rapid-gui again.'")
 	sys.exit(1)
 
-
 def main():
 	""" PyQt4 GUI entry point."""
 	#we could probably share this parser between cli and gui ...
@@ -36,19 +33,14 @@ def main():
 
 	# TODO: QtUserInteraction should be written and used here.
 	# (+ some more refactors to allow a graphical progress bar too.)
-	ui = TextUserInteraction()
+	#ui = TextUserInteraction()
 
-	if options.datadir:
-		init(options.datadir, ui)
-	elif options.unitsync:
-		init(get_writable_data_directory(), ui)
-	elif os.name == 'posix':
-		init(os.path.expanduser('~/.spring'), ui)
-	else:
-		print 'No data directory specified. Specify one using either --datadir or --unitsync.'
-		print
 
 	app = QtGui.QApplication(['RapidGUI'])
-	window = RapidGUI()
+	app.setOrganizationName("SpringRTS");
+	app.setOrganizationDomain("SpringRTS.com");
+	app.setApplicationName("rapid-gui");
+	window = RapidGUI(options)
 	window.show()
-	app.exec_()
+	sys.exit(app.exec_())
+	
