@@ -25,7 +25,7 @@ Where the different verbs and their arguments are:
  * `uninstall-unpinned`: Keep only the pinned tags and all dependencies.
  * `collect-pool`: Remove pool files not needed by any installed package.
  * `make-sdd <tag|package> <dir>`: Extract pool files of a package into
-	`~/.spring/mods/<dir>`.
+	`~/.spring/games/<dir>`.
 
 Examples:
 
@@ -93,11 +93,11 @@ def main():
 	if options.version:
 		# Only the left side is expanded by git-archive, so when the left side
 		# and the right side differ we are running a real release.
-		if 'cf013d5 (HEAD, v0.5.1, master)'[1:-1] == 'Format:%h%d':
+		if 'f7b4588 (HEAD, v0.6.0, master)'[1:-1] == 'Format:%h%d':
 			print 'No version information available.',
 			print 'Are you using a development version?'
 		else:
-			print 'Exported from git commit: cf013d5 (HEAD, v0.5.1, master)'
+			print 'Exported from git commit: f7b4588 (HEAD, v0.6.0, master)'
 		sys.exit(0)
 
 	if len(args) < 1:
