@@ -1,5 +1,5 @@
 import os, ctypes
-from ctypes import c_bool, c_char, c_char_p, c_int, c_uint, c_float, Structure, create_string_buffer, cast, pointer
+from ctypes import c_bool, POINTER, c_ushort, c_char, c_char_p, c_int, c_uint, c_float, Structure, create_string_buffer, cast, pointer
 
 class StartPos(Structure):
 	_fields_ = [('x', c_int), ('y', c_int)]
@@ -63,6 +63,7 @@ class Unitsync:
 		self._init("GetMapInfo", c_int)
 		self._init("GetMapCount", c_int)
 		self._init("GetMapName", c_char_p)
+		self._init("GetMapFileName", c_char_p)
 		self._init("GetMapDescription", c_char_p)
 		self._init("GetMapAuthor", c_char_p)
 		self._init("GetMapWidth", c_int)
@@ -84,7 +85,7 @@ class Unitsync:
 		self._init("GetMapArchiveName", c_char_p)
 		self._init("GetMapChecksum", c_uint)
 		self._init("GetMapChecksumFromName", c_uint)
-		self._init("GetMinimap", pointer)
+		self._init("GetMinimap", POINTER(c_ushort))
 		self._init("GetInfoMapSize", c_int)
 		self._init("GetInfoMap", c_int)
 		self._init("GetSkirmishAICount", c_int)
@@ -192,10 +193,11 @@ class Unitsync:
 	def RemoveAllArchives(self): return self.unitsync.RemoveAllArchives()
 	def GetArchiveChecksum(self, arname): return self.unitsync.GetArchiveChecksum(arname)
 	def GetArchivePath(self, arname): return self.unitsync.GetArchivePath(arname)
-	def GetMapInfoEx(self, name, outInfo, version): return self.unitsync.GetMapInfoEx(name, pointer(outInfo), version)
-	def GetMapInfo(self, name, outInfo): return self.unitsync.GetMapInfo(name, pointer(outInfo))
+	def GetMapInfoEx(self, mapName, outInfo, version): return self.unitsync.GetMapInfoEx(mapName, pointer(outInfo), version)
+	def GetMapInfo(self, mapName, outInfo): return self.unitsync.GetMapInfo(mapName, pointer(outInfo))
 	def GetMapCount(self): return self.unitsync.GetMapCount()
 	def GetMapName(self, index): return self.unitsync.GetMapName(index)
+	def GetMapFileName(self, index): return self.unitsync.GetMapFileName(index)
 	def GetMapDescription(self, index): return self.unitsync.GetMapDescription(index)
 	def GetMapAuthor(self, index): return self.unitsync.GetMapAuthor(index)
 	def GetMapWidth(self, index): return self.unitsync.GetMapWidth(index)
@@ -211,15 +213,15 @@ class Unitsync:
 	def GetMapPosCount(self, index): return self.unitsync.GetMapPosCount(index)
 	def GetMapPosX(self, index, posIndex): return self.unitsync.GetMapPosX(index, posIndex)
 	def GetMapPosZ(self, index, posIndex): return self.unitsync.GetMapPosZ(index, posIndex)
-	def GetMapMinHeight(self, name): return self.unitsync.GetMapMinHeight(name)
-	def GetMapMaxHeight(self, name): return self.unitsync.GetMapMaxHeight(name)
+	def GetMapMinHeight(self, mapName): return self.unitsync.GetMapMinHeight(mapName)
+	def GetMapMaxHeight(self, mapName): return self.unitsync.GetMapMaxHeight(mapName)
 	def GetMapArchiveCount(self, mapName): return self.unitsync.GetMapArchiveCount(mapName)
 	def GetMapArchiveName(self, index): return self.unitsync.GetMapArchiveName(index)
 	def GetMapChecksum(self, index): return self.unitsync.GetMapChecksum(index)
 	def GetMapChecksumFromName(self, mapName): return self.unitsync.GetMapChecksumFromName(mapName)
 	def GetMinimap(self, filename, miplevel): return self.unitsync.GetMinimap(filename, miplevel)
-	def GetInfoMapSize(self, filename, name, width, height): return self.unitsync.GetInfoMapSize(filename, name, width, height)
-	def GetInfoMap(self, filename, name, data, typeHint): return self.unitsync.GetInfoMap(filename, name, pointer(data), typeHint)
+	def GetInfoMapSize(self, mapName, name, width, height): return self.unitsync.GetInfoMapSize(mapName, name, width, height)
+	def GetInfoMap(self, mapName, name, data, typeHint): return self.unitsync.GetInfoMap(mapName, name, pointer(data), typeHint)
 	def GetSkirmishAICount(self): return self.unitsync.GetSkirmishAICount()
 	def GetSkirmishAIInfoCount(self, index): return self.unitsync.GetSkirmishAIInfoCount(index)
 	def GetInfoKey(self, index): return self.unitsync.GetInfoKey(index)
@@ -243,7 +245,7 @@ class Unitsync:
 	def GetSideCount(self): return self.unitsync.GetSideCount()
 	def GetSideName(self, side): return self.unitsync.GetSideName(side)
 	def GetSideStartUnit(self, side): return self.unitsync.GetSideStartUnit(side)
-	def GetMapOptionCount(self, name): return self.unitsync.GetMapOptionCount(name)
+	def GetMapOptionCount(self, mapName): return self.unitsync.GetMapOptionCount(mapName)
 	def GetModOptionCount(self): return self.unitsync.GetModOptionCount()
 	def GetCustomOptionCount(self, filename): return self.unitsync.GetCustomOptionCount(filename)
 	def GetOptionKey(self, optIndex): return self.unitsync.GetOptionKey(optIndex)
